# =============================================================================
# begin of file *gui_SperoData.py*
# =============================================================================
# with function from the publication Primpke, S., C. Lorenz, R. Rascher-Friesenhausen, and G. Gerdts. 2017. 'An automated approach for microplastics analysis using focal plane array (FPA) FTIR microscopy and image analysis', Anal. Methods, 9: 1499-511.
#sprimpke@awi.de (c) 2019


# module imports
# =============================================================================
import tkinter
from tkinter import filedialog

import os
from ECQCLdatanalysis_script import analyse_file
#from idlelib.ToolTip import ToolTip

# class defs
# =============================================================================

class MyApp(tkinter.Frame):
    
    def __init__(self, master):
        tkinter.Frame.__init__(self, master)
        self.grid()

        self.__file_name = 'Select Data File!'
        self.got_file_name = False
        self.file_name = tkinter.StringVar()
        self.file_name.set(self.__file_name)
        #self.__dir_name = 'Select Results Dir!'
        #self.got_dir_name = False
        #self.dir_name = tkinter.StringVar()
       # self.dir_name.set(self.__dir_name)
        self.__fieldsize ='480'
        self.fieldsize = tkinter.StringVar()
        self.fieldsize.set(self.__fieldsize)
        self.__mosaicx = '6'
        self.mosaicx = tkinter.StringVar()
        self.mosaicx.set(self.__mosaicx)
        self.__mosaicy = '6'
        self.mosaicy = tkinter.StringVar()
        self.mosaicy.set(self.__mosaicy)
        self.__pixelsize = '4.1875'
        self.setpixelsize = tkinter.StringVar()
        self.setpixelsize.set(self.__pixelsize)
        self.been_analysed = False
        self.createWidgets()
        
        return
        
    def createWidgets(self):
        self.file_btn = tkinter.Button(self, text="file name", width=25)
        self.file_btn["command"] = self.get_file_name
        #self.result_btn = tkinter.Button(self, text="result dir", width=15)
        #self.result_btn["command"] = self.get_dir_name
        self.start_btn = tkinter.Button(self, text="Analyse from EC-QCL", width=25)
        self.start_btn["command"] = self.run
        self.filelist_btn = tkinter.Button(self, text="Analyse Filelist from EC-QCL", width=25)
        self.filelist_btn["command"] = self.FTIR_run
        self.FTIR_btn = tkinter.Button(self, text="Analyse from FTIR", width=25)
        self.FTIR_btn["command"] = self.FTIR_run        
        self.exit_btn = tkinter.Button(self, text="exit", width=25)
        self.exit_btn["command"] = self.quit
        self.pixelsize_btn = tkinter.Button(self, text="Set Parameters", width=25)
        self.pixelsize_btn["command"] = self.settopixelsize
        self.label_field = tkinter.Label(self, text='FPA datapoints in x and y', width=25)
        self.label_mosaicx = tkinter.Label(self, text='Number of fields in x', width=25)
        self.label_mosaicy = tkinter.Label(self, text='Number of fields in y', width=25)
        
        #file_ttp = ToolTip(self.file_btn, "Select data file")
        #result_ttp = ToolTip(self.result_btn, "Select results directory")
        #start_ttp = ToolTip(self.start_btn, "Run analysis")
        #exit_ttp = ToolTip(self.exit_btn, "Exit application")
        
        self.file_ent = tkinter.Entry(self, fg='red',
                                      textvariable=self.file_name, 
                                      state="readonly", width=20)
        self.field_ent = tkinter.Entry(self, fg='red',
                                     textvariable=self.fieldsize, 
                                      width=20)
        self.x_ent = tkinter.Entry(self, fg='red',
                                     textvariable=self.mosaicx, 
                                      width=20)  
        self.y_ent = tkinter.Entry(self, fg='red',
                                     textvariable=self.mosaicy, 
                                      width=20)                                       
        self.pixelsize_ent = tkinter.Entry(self, fg='red',
                                     textvariable=self.setpixelsize, 
                                     width=20)
        
        self.file_btn.grid(row=0, column=0)
        #self.result_btn.grid(row=1, column=0)
        self.label_field.grid(row=1, column=0)
        self.label_mosaicx.grid(row=2, column=0)
        self.label_mosaicy.grid(row=3, column=0)
        self.pixelsize_btn.grid(row=4, column=0)
        
        
        self.file_ent.grid(row=0, column=1)
        self.field_ent.grid(row=1, column=1)
        self.x_ent.grid(row=2, column=1) 
        self.y_ent.grid(row=3, column=1)
        self.pixelsize_ent.grid(row=4, column=1)

        self.start_btn.grid(row=0, column=2)
        #self.filelist_btn.grid(row=1, column=2) 
        self.FTIR_btn.grid(row=1, column=2) 
        self.exit_btn.grid(row=4, column=2)
        return
    # Read in of the file name    
    def get_file_name(self):
        self.__file_name = file_name = filedialog.askopenfilename()
        head, tail = os.path.split(file_name)
        self.file_ent['fg'] = 'black'
        self.file_name.set(tail)
        self.got_file_name = True
        self.been_analysed = False
        return
    # Setting the dictoniary for results. The dictoniary should be in the same folder as the script   
    def get_dir_name(self):
        self.__dir_name = dir_name = filedialog.askdirectory()
        head, tail = os.path.split(dir_name)
        self.dir_ent['fg'] = 'black'
        self.dir_name.set(tail)
        self.got_dir_name = True
        return
    # Setting of the pixelsize
    def settopixelsize(self):
        self.__pixelsize = self.setpixelsize.get()
        self.pixelsize_ent['fg'] = 'black'
        self.__fieldsize = self.fieldsize.get()
        self.field_ent['fg'] = 'black'
        self.__mosaicx = self.mosaicx.get()
        self.x_ent['fg'] = 'black'
        self.__mosaicy = self.mosaicy.get()
        self.y_ent['fg'] = 'black'
        return
        
    # Starting the script   
    def run(self):
        if not self.been_analysed:
            self.been_analysed = False
            if self.got_file_name:
                print("running...") 
                print(self.__pixelsize) 
                analyse_file(self.__file_name,int(self.__fieldsize),int(self.__fieldsize),int(self.__mosaicx),int(self.__mosaicy),float(self.__pixelsize),Matlab=True,FTIR=False,QC=True,Matlabfilelist=False)
                self.been_analysed = True
            
        return
    
    def FTIR_run(self):
        if not self.been_analysed:
            self.been_analysed = False
            if self.got_file_name:
                print("running...") 
                print(self.__pixelsize)               
                analyse_file(self.__file_name,int(self.__fieldsize),int(self.__fieldsize),int(self.__mosaicx),int(self.__mosaicy),float(self.__pixelsize),Matlab=True,FTIR=True,QC=True,Matlabfilelist=False)
                self.been_analysed = True
            
        return


        
# script entry
# =============================================================================
        
root = tkinter.Tk()
root.title("EC-QCL Data Analysis Tool Version 1.0.0")
app = MyApp(root)
root.mainloop()
        
# =============================================================================
# end of file *gui_fiber_version1.p*
# =============================================================================
